==> plugin-api-1.2.2-sources.jar: com/xebialabs/deployit/ConfigurationItem.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Specifies that this class is a configuration item.
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
public @interface ConfigurationItem {

	/**
	 * The description of this configuration item.
	 */
	String description() default "Description unavailable";

	/**
	 * The category of this configuration item, e.g. "Middleware" or
	 * "Deployments". This determines where the configuration item will appear
	 * in the navigation tree in the UI.
	 * <p>
	 * If no value is supplied, configuration items of this type will only show
	 * up when you select the "All" category in the user interface.
	 */
	String category() default "";

	/**
	 * Whether this configuration can be expanded in the navigation tree in the
	 * UI.
	 */
	boolean expandable() default false;

	/**
	 * The mapping types for which this configuration item can be a source. This
	 * configuration item can be the source for these types and their subtypes.
	 */
	// should be Class<? extends Mapping> but Mapping isn't part of the API
	Class<?>[] sourceForMappingTypes() default {};

	/**
	 * The mapping types for which this configuration item can be a target. This
	 * configuration item can be the target for these types and their subtypes.
	 */
	// should be Class<? extends Mapping> but Mapping isn't part of the API
	Class<?>[] targetForMappingTypes() default {};

}

==> plugin-api-1.3.2-sources.jar: com/xebialabs/deployit/ConfigurationItem.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Specifies that this class is a configuration item.
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
public @interface ConfigurationItem {

	/**
	 * The description of this configuration item.
	 */
	String description() default "Description unavailable";

	/**
	 * The category of this configuration item, e.g. "Middleware" or
	 * "Deployments". This determines where the configuration item will appear
	 * in the navigation tree in the UI.
	 * <p>
	 * If no value is supplied, configuration items of this type will only show
	 * up when you select the "All" category in the user interface.
	 */
	String category() default "";

	/**
	 * Whether this configuration item can be discovered, that is, can try to check its
	 * own properties in Reality.
	 * 
	 * When this property is set to 'true', the plugin loader checks that the CI implements
	 * the 'Discoverable' interface and throws an error if not. 
	 */
	boolean discoverable() default false;

}
